@@ -59,6 +59,7 @@ MainWindow::MainWindow (QWidget *parent)
 , mqThread (QString("qgvdial:%1").arg(QHostInfo::localHostName())
             .toLatin1().constData (), this)
 #endif
+, jar (NULL)
 {
     initLogging ();
 
@@ -108,6 +109,22 @@ MainWindow::~MainWindow ()
         delete vmailPlayer;
         vmailPlayer = NULL;
     }
+
+    if (NULL != jar) {
+        CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+        dbMain.saveCookies (jar);
+    }
+
+    // Dump the log one last time.
+    QMutexLocker locker(&logMutex);
+    for (int i = 0; i < arrLogTextStream.size(); i++) {
+        // Send to log file
+        if (fLogfile.isOpen ()) {
+            QTextStream streamLog(&fLogfile);
+            streamLog << arrLogTextStream[i] << endl;
+        }
+    }
+    arrLogTextStream.clear ();
 }//MainWindow::~MainWindow
 
 /** Initialize the log file name and timer.
@@ -133,7 +150,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.693");
+    setStatus("Using qgvdial version 0.2.697");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -168,15 +185,10 @@ MainWindow::log (const QString &strText, int level /*= 10*/)
     cout << strLog.toStdString () << endl;
 
     if (level <= logLevel) {
-        // Send to log file
-        if (fLogfile.isOpen ()) {
-            QTextStream streamLog(&fLogfile);
-            streamLog << strLog << endl;
-        }
-
         // Append it to the circular buffer
         QMutexLocker locker(&logMutex);
         arrLogMsgs.prepend (strLog);
+        arrLogTextStream.append (strLog);
         bKickLocksTimer = true;
     }
 }//MainWindow::log
@@ -193,6 +205,15 @@ MainWindow::onCleanupLogsArray()
         bKickLocksTimer = false;
         timeout = 1 * 1000;
 
+        for (int i = 0; i < arrLogTextStream.size(); i++) {
+            // Send to log file
+            if (fLogfile.isOpen ()) {
+                QTextStream streamLog(&fLogfile);
+                streamLog << arrLogTextStream[i] << endl;
+            }
+        }
+        arrLogTextStream.clear ();
+
         while (arrLogMsgs.size () > 50) {
             arrLogMsgs.removeLast ();
         }
@@ -351,6 +372,11 @@ MainWindow::init ()
         this, SLOT(onRegPhoneSelectionChange(int)),
         this, SIGNAL(regPhoneChange(const QStringList &,int)));
 
+    // Set up cookies
+    jar = new CookieJar(this);
+    dbMain.loadCookies (jar);
+    webPage.nwAccessMgr()->setCookieJar (jar);
+
     // The GV access class signals these during the dialling protocol
     rv = connect (&webPage    , SIGNAL (dialInProgress (const QString &)),
                        this       , SLOT   (dialInProgress (const QString &)));
@@ -432,7 +458,7 @@ MainWindow::init ()
 #ifdef Q_WS_MAEMO_5
     // Dismiss = Esc
     actDismiss.setShortcut (QKeySequence(Qt::CTRL + Qt::Key_W));
-#else
+#elif !MOBILE_OS
     // Dismiss = Esc
     actDismiss.setShortcut (QKeySequence(Qt::Key_Escape));
 #endif
